aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc-nt.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-dcerpc-nt.c')
-rw-r--r--epan/dissectors/packet-dcerpc-nt.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-dcerpc-nt.c b/epan/dissectors/packet-dcerpc-nt.c
index a869e2c90e..798db3e289 100644
--- a/epan/dissectors/packet-dcerpc-nt.c
+++ b/epan/dissectors/packet-dcerpc-nt.c
@@ -7,8 +7,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@
/*
* This file contains helper routines that are used by the DCERPC over SMB
* dissectors for ethereal.
*/
/*
@@ -1684,7 +1684,7 @@ void dcerpc_smb_init(int proto_dcerpc)
{ "Unknown char", "nt.unknown.char",
FT_UINT8, BASE_HEX, NULL, 0x0,
"Unknown char. If you know what this is, contact "
- "ethereal developers.", HFILL }},
+ "wireshark developers.", HFILL }},
/* Misc */
@@ -7,8 +7,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
@@ -41,7 +41,7 @@
/*
* This file contains helper routines that are used by the DCERPC over SMB
- * dissectors for ethereal.
+ * dissectors for wireshark.
*/
/*